@@ -3,8 +3,6 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from __future__ import print_function
-
 import sys
 
 from collections import defaultdict
@@ -188,7 +186,7 @@ class CommandInvoker(object):
             deprecate_kwargs['object_type'] = 'command'
             del deprecate_kwargs['_get_tag']
             del deprecate_kwargs['_get_message']
-            deprecations.append(ImplicitDeprecated(**deprecate_kwargs))
+            deprecations.append(ImplicitDeprecated(cli_ctx=self.cli_ctx, **deprecate_kwargs))
 
         # search for implicit preview
         path_comps = cmd.name.split()[:-1]
@@ -200,7 +198,7 @@ class CommandInvoker(object):
         if implicit_preview_info:
             preview_kwargs = implicit_preview_info.__dict__.copy()
             preview_kwargs['object_type'] = 'command'
-            previews.append(ImplicitPreviewItem(**preview_kwargs))
+            previews.append(ImplicitPreviewItem(cli_ctx=self.cli_ctx, **preview_kwargs))
 
         # search for implicit experimental
         path_comps = cmd.name.split()[:-1]
@@ -212,7 +210,7 @@ class CommandInvoker(object):
         if implicit_experimental_info:
             experimental_kwargs = implicit_experimental_info.__dict__.copy()
             experimental_kwargs['object_type'] = 'command'
-            experimentals.append(ImplicitExperimentalItem(**experimental_kwargs))
+            experimentals.append(ImplicitExperimentalItem(cli_ctx=self.cli_ctx, **experimental_kwargs))
 
         if not self.cli_ctx.only_show_errors:
             for d in deprecations:
@@ -232,4 +230,5 @@ class CommandInvoker(object):
         return CommandResultItem(event_data['result'],
                                  exit_code=0,
                                  table_transformer=cmd_tbl[parsed_args.command].table_transformer,
-                                 is_query_active=self.data['query_active'])
+                                 is_query_active=self.data['query_active'],
+                                 raw_result=cmd_result)
