@@ -4,10 +4,7 @@
 # --------------------------------------------------------------------------------------------
 
 import unittest
-try:
-    import mock
-except ImportError:
-    from unittest import mock
+from unittest import mock
 
 from knack.arguments import ArgumentsContext
 from knack.commands import CLICommandsLoader, CommandGroup
@@ -66,7 +63,7 @@ class TestCommandDeprecation(unittest.TestCase):
         with self.assertRaises(SystemExit):
             self.cli_ctx.invoke('-h'.split())
         actual = self.io.getvalue()
-        expected = u"""
+        expected = """
 Group
     {}
 
@@ -432,7 +429,7 @@ Arguments
         """ Ensure non-expired options can be used without warning. """
         self.cli_ctx.invoke('arg-test --arg1 foo --opt1 bar --opt5 foo'.split())
         actual = self.io.getvalue()
-        self.assertTrue(u'--alt5' not in actual and u'--opt5' not in actual)
+        self.assertTrue('--alt5' not in actual and '--opt5' not in actual)
 
     @redirect_io
     def test_deprecate_options_execute_expiring(self):
